@@ -46,11 +46,9 @@ class Recipe(object):
             options["location"], "bin", options["executable-name"])
 
         # explore the real Python, store fingerprint
-        real = options["real-python"]
-        options["__real-executable__"] = real
         options["__python-version__"] = subprocess.Popen(
-            [real, "-c", "import sys; print sys.version; "
-                         "print sys.prefix; print sys.exec_prefix"],
+            [options["real-python"], "-c", "import sys; " +
+             "print sys.version; print sys.prefix; print sys.exec_prefix"],
             stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()[0]
 
     def install(self):
@@ -58,7 +56,6 @@ class Recipe(object):
         location = options["location"]
         executable = options["executable"]
 
-        real = options["__real-executable__"]
         pythonx_y = "python" + options["__python-version__"][:3]
         prefix, exec_prefix = options["__python-version__"].splitlines()[-2:]
 
@@ -68,7 +65,7 @@ class Recipe(object):
 
         # copy the executable
         os.mkdir(join(location, "bin"))
-        shutil.copy(real, executable)
+        shutil.copy(options["real-python"], executable)
 
         # link standard modules
         lib = join(location, "lib", pythonx_y)
@@ -111,6 +108,9 @@ class Recipe(object):
 
         return [location, bin]
 
+    def update(self):
+        pass
+
 
 def boolean(value):
     return value.lower() in (1, "yes", "true", "on")
